@@ -11,7 +11,7 @@
 
 {- |
 Module      :  Lens.Micro
-Copyright   :  (C) 2013-2016 Edward Kmett, 2015-2016 Artyom
+Copyright   :  (C) 2013-2016 Edward Kmett, 2015-2016 Artyom Kazak, 2018 Monadfix
 License     :  BSD-style (see the file LICENSE)
 
 This module provides the essential functionality. There are other packages in the microlens family – mix and match them at will. If you're writing an app, you want <http://hackage.haskell.org/package/microlens-platform microlens-platform> – it provides the most functionality.
@@ -38,7 +38,7 @@ module Lens.Micro
   -- $setters-note
   ASetter, ASetter',
   sets,
-  (%~), over,
+  (%~), over, (+~), (-~),
   (<>~),
   (.~), set,
   (?~),
@@ -303,6 +303,53 @@ over :: ASetter s t a b -> (a -> b) -> s -> t
 over l f = runIdentity #. l (Identity #. f)
 {-# INLINE over #-}
 
+
+-- | Increment the target(s) of a numerically valued 'Lens' or 'Traversal'.
+--
+-- >>> (a,b) & _1 +~ c
+-- (a + c,b)
+--
+-- >>> (a,b) & both +~ c
+-- (a + c,b + c)
+--
+-- >>> (1,2) & _2 +~ 1
+-- (1,3)
+--
+-- >>> [(a,b),(c,d)] & traverse.both +~ e
+-- [(a + e,b + e),(c + e,d + e)]
+--
+-- @
+-- ('+~') :: 'Num' a => 'Lens'' s a      -> a -> s -> s
+-- ('+~') :: 'Num' a => 'Traversal'' s a -> a -> s -> s
+-- @
+(+~) :: Num a => ASetter s t a a -> a -> s -> t
+l +~ n = over l (+ n)
+{-# INLINE (+~) #-}
+
+-- | Decrement the target(s) of a numerically valued 'Lens', or 'Traversal'.
+--
+-- >>> (a,b) & _1 -~ c
+-- (a - c,b)
+--
+-- >>> (a,b) & both -~ c
+-- (a - c,b - c)
+--
+-- >>> _1 -~ 2 $ (1,2)
+-- (-1,2)
+--
+-- >>> mapped.mapped -~ 1 $ [[4,5],[6,7]]
+-- [[3,4],[5,6]]
+--
+-- @
+-- ('-~') :: 'Num' a => 'Lens'' s a      -> a -> s -> s
+-- ('-~') :: 'Num' a => 'Traversal'' s a -> a -> s -> s
+-- @
+(-~) :: Num a => ASetter s t a a -> a -> s -> t
+l -~ n = over l (subtract n)
+{-# INLINE (-~) #-}
+
+
+
 {- |
 ('<>~') appends a value monoidally to the target.
 
